@@ -1,10 +1,10 @@
-/*  
-  TheengsDecoder  - Decode things and devices
+/*
+    TheengsDecoder - Decode things and devices
 
     Copyright: (c)Florian ROBERT
-  
+
     This file is part of TheengsDecoder.
-    
+
     TheengsDecoder is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -26,15 +26,17 @@
 #include "devices/CGP1W_json.h"
 #include "devices/CGPR1_json.h"
 #include "devices/GAEN_json.h"
+#include "devices/H5055_json.h"
 #include "devices/H5072_json.h"
 #include "devices/H5075_json.h"
 #include "devices/H5102_json.h"
 #include "devices/HHCCJCY01HHCC_json.h"
+#include "devices/HHCCPOT002_json.h"
 #include "devices/IBS_TH1_json.h"
 #include "devices/IBS_TH2_json.h"
 #include "devices/IBT_2X_json.h"
 #include "devices/IBT_4XS_json.h"
-#include "devices/IBT_6XS_json.h"
+#include "devices/IBT_6XS_SOLIS6_json.h"
 #include "devices/JQJCY01YM_json.h"
 #include "devices/LYWSD02_json.h"
 #include "devices/LYWSD03MMC_ATC_json.h"
@@ -47,8 +49,9 @@
 #include "devices/Mokobeacon_json.h"
 #include "devices/RuuviTag_RAWv1_json.h"
 #include "devices/RuuviTag_RAWv2_json.h"
+#include "devices/SBMT_json.h"
+#include "devices/SBS1_json.h"
 #include "devices/TPMS_json.h"
-#include "devices/VEGTRUG_json.h"
 #include "devices/WS02_json.h"
 #include "devices/WS08_json.h"
 #include "devices/XMTZC04HM_json.h"
@@ -56,11 +59,9 @@
 #include "devices/iBeacon_json.h"
 #include "devices/iNode_json.h"
 #include "devices/BM_V23_json.h"
-#include "devices/SOLIS_6_json.h"
 
 const char* _devices[][2] = {
     {_HHCCJCY01HHCC_json, _HHCCJCY01HHCC_json_props},
-    {_VEGTRUG_json, _VEGTRUG_json_props},
     {_LYWSD02_json, _LYWSD02_json_props},
     {_LYWSDCGQ_json, _LYWSDCGQ_json_props},
     {_CGP1W_json, _CGP1W_json_props},
@@ -73,7 +74,7 @@ const char* _devices[][2] = {
     {_IBS_TH1_json, _IBS_TH1_json_props},
     {_IBS_TH2_json, _IBS_TH2_json_props},
     {_IBT_4XS_json, _IBT_4XS_json_props},
-    {_IBT_6XS_json, _IBT_6XS_json_props},
+    {_IBT_6XS_SOLIS6_json, _IBT_6XS_SOLIS6_json_props},
     {_Miband_json, _Miband_json_props},
     {_XMTZC04HM_json, _XMTZC04HM_json_props},
     {_XMTZC05HM_json, _XMTZC05HM_json_props},
@@ -83,6 +84,7 @@ const char* _devices[][2] = {
     {_ibeacon_json, _ibeacon_json_props},
     {_WS02_json, _WS02_json_props},
     {_WS08_json, _WS08_json_props},
+    {_H5055_json, _H5055_json_props},
     {_H5075_json, _H5075_json_props},
     {_H5072_json, _H5072_json_props},
     {_H5102_json, _H5102_json_props},
@@ -94,8 +96,10 @@ const char* _devices[][2] = {
     {_IBT_2X_json, _IBT_2X_json_props},
     {_RuuviTag_RAWv1_json, _RuuviTag_RAWv1_json_props},
     {_RuuviTag_RAWv2_json, _RuuviTag_RAWv2_json_props},
+    {_SBMT_json, _SBMT_json_props},
+    {_SBS1_json, _SBS1_json_props},
     {_BM_V23_json, _BM_V23_json_props},
     {_MS_CDP_json, _MS_CDP_json_props},
     {_GAEN_json, _GAEN_json_props},
-    {_SOLIS_6_json, _SOLIS_6_json_props},
+    {_HHCCPOT002_json, _HHCCPOT002_json_props},
 };
