@@ -7,7 +7,7 @@ const char* _H5102_json = "{\"brand\":\"Govee\",\"model\":\"Smart Thermo Hygrome
    "brand":"Govee",
    "model":"Smart Thermo Hygrometer",
    "model_id":"H5102",
-   "condition":["name", "contain", "GVH5102","&"","manufacturerdata", "index", 0, "0100"],
+   "condition":["name", "contain", "GVH5102", "&", "manufacturerdata", "index", 0, "0100"],
    "properties":{
       "tempc":{
          "decoder":["value_from_hex_data", "manufacturerdata", 8, 6, false],
