@@ -1,10 +1,10 @@
-""" 
+"""
   TheengsGateway - Decode things and devices and publish data to an MQTT broker
 
     Copyright: (c)Florian ROBERT
-  
+
     This file is part of TheengsGateway.
-    
+
     TheengsGateway is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -33,8 +33,12 @@ default_config = {
     "ble_scan_time":5,
     "ble_time_between_scans":5,
     "publish_topic": "home/TheengsGateway/BTtoMQTT",
-    "subscribe_topic": "home/TheengsGateway/commands",
-    "log_level": "WARNING"
+    "subscribe_topic": "home/TheengsGateway/+",
+    "log_level": "WARNING",
+    "discovery": 1,
+    "discovery_topic": "homeassistant/sensor",
+    "discovery_device_name": "TheengsGateway",
+    "discovery_filter": ["IBEACON", "GAEN", "MS-CDP"]
 }
 
 conf_path = os.path.expanduser('~') + '/theengsgw.conf'
@@ -46,10 +50,16 @@ parser.add_argument('-u', '--user', dest='user', type=str, help="MQTT username")
 parser.add_argument('-p', '--pass', dest='pwd', type=str, help="MQTT password")
 parser.add_argument('-pt', '--pub_topic', dest='pub_topic', type=str, help="MQTT publish topic")
 parser.add_argument('-st', '--sub_topic', dest='sub_topic', type=str, help="MQTT subscribe topic")
+parser.add_argument('-pa', '--publish_all', dest='publish_all', type=int, help="Enable(1) or disable(0) publishing of all beacons")
 parser.add_argument('-sd', '--scan_duration', dest='scan_dur', type=int, help="BLE scan duration (seconds)")
 parser.add_argument('-tb', '--time_between', dest='time_between', type=int, help="Seconds to wait between scans")
 parser.add_argument('-ll', '--log_level', dest='log_level', type=str, help="TheengsGateway log level",
                     choices=['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL'])
+parser.add_argument('-Dt', '--discovery-topic', dest='discovery_topic', type=str, help="MQTT Discovery topic")
+parser.add_argument('-D', '--discovery', dest='discovery', type=int, help="Enable(1) or disable(0) MQTT discovery")
+parser.add_argument('-Dn', '--discovery_name', dest='discovery_device_name', type=str, help="Device name for Home Assistant")
+parser.add_argument('-Df', '--discovery_filter', dest='discovery_filter', nargs='+', default=[],
+                    help="Device discovery filter list for Home Assistant")
 args = parser.parse_args()
 
 try:
@@ -70,6 +80,8 @@ if args.pub_topic:
     config['publish_topic'] = args.pub_topic
 if args.sub_topic:
     config['subscribe_topic'] = args.sub_topic
+if args.publish_all:
+    config['publish_all'] = args.publish_all
 if args.scan_dur:
     config['ble_scan_time'] = args.scan_dur
 if args.time_between:
@@ -77,6 +89,32 @@ if args.time_between:
 if args.log_level:
     config['log_level'] = args.log_level
 
+if args.discovery is not None:
+    config['discovery'] = args.discovery
+elif not 'discovery' in config.keys():
+    config['discovery'] = default_config['discovery']
+    config['discovery_topic'] = default_config['discovery_topic']
+    config['discovery_device_name'] = default_config['discovery_device_name']
+    config['discovery_filter'] = default_config['discovery_filter']
+
+if args.discovery_topic:
+    config['discovery_topic'] = args.discovery_topic
+elif not 'discovery_topic' in config.keys():
+    config['discovery_topic'] = default_config['discovery_topic']
+
+if args.discovery_device_name:
+    config['discovery_device_name'] = args.discovery_device_name
+elif not 'discovery_device_name' in config.keys():
+    config['discovery_device_name'] = default_config['discovery_device_name']
+
+if args.discovery_filter:
+    config['discovery_filter'] = default_config['discovery_filter']
+    if args.discovery_filter[0] != "reset":
+        for item in args.discovery_filter:
+            config['discovery_filter'].append(item)
+elif not 'discovery_filter' in config.keys():
+    config['discovery_filter'] = default_config['discovery_filter']
+
 if not config['host']:
     sys.exit('Invalid MQTT host')
 
