@@ -1,10 +1,10 @@
-""" 
+"""
   TheengsGateway - Decode things and devices and publish data to an MQTT broker
 
     Copyright: (c)Florian ROBERT
-  
+
     This file is part of TheengsGateway.
-    
+
     TheengsGateway is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -46,10 +46,10 @@ class gateway:
         def on_connect(client, userdata, flags, rc):
             if rc == 0:
                 logger.info("Connected to MQTT Broker!")
-                client.subscribe(self.sub_topic)
+                self.subscribe(self.sub_topic)
             else:
                 logger.error(f"Failed to connect to MQTT broker %s:%d rc: %d" % (self.broker, self.port, rc))
-                client.connect(self.broker, self.port)
+                self.client.connect(self.broker, self.port)
 
         def on_disconnect(client, userdata,rc=0):
             logger.error(f"Disconnected rc = %d" % (rc))
@@ -58,14 +58,31 @@ class gateway:
         self.client.username_pw_set(self.username, self.password)
         self.client.on_connect = on_connect
         self.client.on_disconnect = on_disconnect
-        self.client.connect(self.broker, self.port)
+        try:
+            self.client.connect(self.broker, self.port)
+        except:
+            pass
 
     def subscribe(self, sub_topic):
         def on_message(client_, userdata, msg):
             logger.info(f"Received `{msg.payload.decode()}` from `{msg.topic}` topic")
+            try:
+                msg_json = json.loads(str(msg.payload.decode()))
+            except:
+                return
+            address = msg_json["id"]
+            decoded_json = decodeBLE(json.dumps(msg_json))
+            if decoded_json:
+                if gw.discovery:
+                    gw.publish_device_info(json.loads(decoded_json)) ## publish sensor data to home assistant mqtt discovery
+                else:
+                    gw.publish(decoded_json, gw.pub_topic + '/' + address.replace(':', ''))
+            elif gw.publish_all:
+                gw.publish(str(msg.payload.decode()), gw.pub_topic + '/' + address.replace(':', ''))
 
         self.client.subscribe(sub_topic)
         self.client.on_message = on_message
+        logger.info(f"Subscribed to {sub_topic}")
 
 
     def publish(self, msg, pub_topic=None):
@@ -95,7 +112,7 @@ class gateway:
                     await asyncio.sleep(5.0)
             except Exception as e:
                 raise e
-    
+
         logger.error('BLE scan loop stopped')
         self.running = False
 
@@ -121,29 +138,25 @@ def detection_callback(device, advertisement_data):
     if data_json:
         data_json['id'] = device.address
         data_json['rssi'] = device.rssi
-        data_json = decodeBLE(json.dumps(data_json))
+        decoded_json = decodeBLE(json.dumps(data_json))
 
-        if data_json:
-           gw.publish(data_json, gw.pub_topic + '/' + device.address.replace(':', ''))
+        if decoded_json:
+            if gw.discovery:
+                gw.publish_device_info(json.loads(decoded_json)) ## publish sensor data to home assistant mqtt discovery
+            else:
+                gw.publish(decoded_json, gw.pub_topic + '/' + device.address.replace(':', ''))
+        elif gw.publish_all:
+            gw.publish(json.dumps(data_json), gw.pub_topic + '/' + device.address.replace(':', ''))
 
 def run(arg):
     global gw
+
     try:
         with open(arg) as config_file:
             config = json.load(config_file)
     except:
         raise SystemExit(f"Invalid File: {sys.argv[1]}")
 
-    try:
-        gw = gateway(config["host"], int(config["port"]), config["user"], config["pass"])
-    except:
-        raise SystemExit(f"Missing or invalid MQTT host parameters")
-
-    gw.scan_time = config.get("ble_scan_time", 5)
-    gw.time_between_scans = config.get("ble_time_between_scans", 0)
-    gw.sub_topic = config.get("subscribe_topic", "gateway_sub")
-    gw.pub_topic = config.get("publish_topic", "gateway_pub")
-
     log_level = config.get("log_level", "WARNING").upper()
     if log_level == "DEBUG":
         log_level = logging.DEBUG
@@ -158,6 +171,24 @@ def run(arg):
     else:
         log_level = logging.WARNING
 
+    if config['discovery']:
+        from .discovery import discovery
+        gw = discovery(config["host"], int(config["port"]), config["user"],
+                       config["pass"], config['discovery_topic'],
+                       config['discovery_device_name'], config['discovery_filter'])
+    else:
+        try:
+          gw = gateway(config["host"], int(config["port"]), config["user"], config["pass"])
+        except:
+          raise SystemExit(f"Missing or invalid MQTT host parameters")
+
+    gw.discovery = config['discovery']
+    gw.scan_time = config.get("ble_scan_time", 5)
+    gw.time_between_scans = config.get("ble_time_between_scans", 0)
+    gw.sub_topic = config.get("subscribe_topic", "gateway_sub")
+    gw.pub_topic = config.get("publish_topic", "gateway_pub")
+    gw.publish_all = config.get("publish_all", 5)
+
     logging.basicConfig()
     logger.setLevel(log_level)
 
